@@ -33,27 +33,22 @@
 #include <NetworkManagerQt/WirelessSetting>
 
 #include <QStringBuilder>
+#include <QDialog>
 
+#include <KConfigGroup>
+#include <KConfig>
 #include <KPluginFactory>
 #include <KWindowSystem>
-#include <KDialog>
-#include <KDebug>
-#include <KConfig>
-#include <KConfigGroup>
 #include <KWallet/Wallet>
+
 #include <QDebug>
 
-SecretAgent::SecretAgent(QObject* parent)
-    : NetworkManager::SecretAgent("org.kde.networkmanagement", parent)
-    , m_openWalletFailed(false)
-    , m_wallet(0)
-    , m_dialog(0)
+SecretAgent::SecretAgent(QObject* parent):
+    NetworkManager::SecretAgent("org.kde.plasma.networkmanagement", parent),
+    m_wallet(0),
+    m_dialog(0)
 {
-    connect(NetworkManager::notifier(), SIGNAL(serviceDisappeared()),
-            this, SLOT(killDialogs()));
-
-    // We have to import secrets previously stored in plaintext files
-    importSecretsFromPlainTextFiles();
+    connect(NetworkManager::notifier(), &NetworkManager::Notifier::serviceDisappeared, this, &SecretAgent::killDialogs);
 }
 
 SecretAgent::~SecretAgent()
@@ -69,10 +64,10 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection, const
     qDebug() << "Hints:" << hints;
     qDebug() << "Flags:" << flags;
 
-    QString callId = connection_path.path() % setting_name;
+    const QString callId = connection_path.path() % setting_name;
     foreach (const SecretsRequest & request, m_calls) {
         if (request == callId) {
-            kWarning() << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path() << setting_name;
+            qWarning() << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path() << setting_name;
             CancelGetSecrets(connection_path, setting_name);
             break;
         }
@@ -96,7 +91,7 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection, const
 
 void SecretAgent::SaveSecrets(const NMVariantMapMap &connection, const QDBusObjectPath &connection_path)
 {
-    kDebug() << connection_path.path();
+    qDebug() << connection_path.path();
 
     setDelayedReply(true);
     SecretsRequest::Type type;
@@ -116,7 +111,7 @@ void SecretAgent::SaveSecrets(const NMVariantMapMap &connection, const QDBusObje
 
 void SecretAgent::DeleteSecrets(const NMVariantMapMap &connection, const QDBusObjectPath &connection_path)
 {
-    kDebug() << connection_path.path();
+    qDebug() << connection_path.path();
 
     setDelayedReply(true);
     SecretsRequest request(SecretsRequest::DeleteSecrets);
@@ -130,7 +125,7 @@ void SecretAgent::DeleteSecrets(const NMVariantMapMap &connection, const QDBusOb
 
 void SecretAgent::CancelGetSecrets(const QDBusObjectPath &connection_path, const QString &setting_name)
 {
-    kDebug() << connection_path.path() << setting_name;
+    qDebug() << connection_path.path() << setting_name;
     QString callId = connection_path.path() % setting_name;
     for (int i = 0; i < m_calls.size(); ++i) {
         SecretsRequest request = m_calls.at(i);
@@ -155,16 +150,7 @@ void SecretAgent::dialogAccepted()
     for (int i = 0; i < m_calls.size(); ++i) {
         SecretsRequest request = m_calls[i];
         if (request.type == SecretsRequest::GetSecrets && request.dialog == m_dialog) {
-            NMStringMap tmpOpenconnectSecrets;
             NMVariantMapMap connection = request.dialog->secrets();
-            if (connection.contains(QLatin1String("vpn"))) {
-                if (connection.value(QLatin1String("vpn")).contains(QLatin1String("tmp-secrets"))) {
-                    QVariantMap vpnSetting = connection.value(QLatin1String("vpn"));
-                    tmpOpenconnectSecrets = qdbus_cast<NMStringMap>(vpnSetting.take(QLatin1String("tmp-secrets")));
-                    connection.insert(QLatin1String("vpn"), vpnSetting);
-                }
-            }
-
             sendSecrets(connection, request.message);
             NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(connection));
             NetworkManager::ConnectionSettings::Ptr completeConnectionSettings;
@@ -188,16 +174,19 @@ void SecretAgent::dialogAccepted()
                         }
                     }
                 } else if (completeConnectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
-                    NetworkManager::WirelessSecuritySetting::Ptr wirelessSecuritySetting = completeConnectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
-                    if (wirelessSecuritySetting && wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap) {
-                        NetworkManager::Security8021xSetting::Ptr security8021xSetting = completeConnectionSettings->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
-                        if (security8021xSetting) {
-                            if (security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodFast) ||
-                                security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodTtls) ||
-                                security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodPeap)) {
-                                if (security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotSaved) ||
-                                    security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotRequired)) {
-                                    requestOffline = false;
+                    NetworkManager::WirelessSetting::Ptr wirelessSetting = completeConnectionSettings->setting(NetworkManager::Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
+                    if (wirelessSetting && !wirelessSetting->security().isEmpty()) {
+                        NetworkManager::WirelessSecuritySetting::Ptr wirelessSecuritySetting = completeConnectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
+                        if (wirelessSecuritySetting && wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap) {
+                            NetworkManager::Security8021xSetting::Ptr security8021xSetting = completeConnectionSettings->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
+                            if (security8021xSetting) {
+                                if (security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodFast) ||
+                                    security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodTtls) ||
+                                    security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodPeap)) {
+                                    if (security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotSaved) ||
+                                        security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotRequired)) {
+                                        requestOffline = false;
+                                    }
                                 }
                             }
                         }
@@ -211,38 +200,6 @@ void SecretAgent::dialogAccepted()
                     requestOffline.saveSecretsWithoutReply = true;
                     m_calls << requestOffline;
                 }
-            } else if (request.saveSecretsWithoutReply && completeConnectionSettings->connectionType() == NetworkManager::ConnectionSettings::Vpn && !tmpOpenconnectSecrets.isEmpty()) {
-                NetworkManager::VpnSetting::Ptr vpnSetting = completeConnectionSettings->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
-                if (vpnSetting) {
-                    NMStringMap data = vpnSetting->data();
-                    NMStringMap secrets = vpnSetting->secrets();
-
-                    // Load secrets from auth dialog which are returned back to NM
-                    if (connection.value(QLatin1String("vpn")).contains(QLatin1String("secrets"))) {
-                        secrets.unite(qdbus_cast<NMStringMap>(connection.value(QLatin1String("vpn")).value(QLatin1String("secrets"))));
-                    }
-
-                    // Load temporary secrets from auth dialog which are not returned to NM
-                    foreach (const QString &key, tmpOpenconnectSecrets.keys()) {
-                        if (secrets.contains(QLatin1String("save_passwords")) && secrets.value(QLatin1String("save_passwords")) == QLatin1String("yes")) {
-                            data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::AgentOwned));
-                        } else {
-                            data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::NotSaved));
-                        }
-
-                        secrets.insert(key, tmpOpenconnectSecrets.value(key));
-                    }
-
-                    vpnSetting->setData(data);
-                    vpnSetting->setSecrets(secrets);
-                    if (!con) {
-                        con = NetworkManager::findConnection(request.connection_path.path());
-                    }
-
-                    if (con) {
-                        con->update(completeConnectionSettings->toMap());
-                    }
-                }
             }
 
             m_calls.removeAt(i);
@@ -292,14 +249,10 @@ void SecretAgent::killDialogs()
 void SecretAgent::walletOpened(bool success)
 {
     if (!success) {
-        m_openWalletFailed = true;
         m_wallet->deleteLater();
         m_wallet = 0;
-    } else {
-        m_openWalletFailed = false;
     }
-
-    processNext();
+    processNext(!success);
 }
 
 void SecretAgent::walletClosed()
@@ -310,26 +263,26 @@ void SecretAgent::walletClosed()
     m_wallet = 0;
 }
 
-void SecretAgent::processNext()
+void SecretAgent::processNext(bool ignoreWallet)
 {
     int i = 0;
     while (i < m_calls.size()) {
         SecretsRequest &request = m_calls[i];
         switch (request.type) {
         case SecretsRequest::GetSecrets:
-            if (processGetSecrets(request)) {
+            if (processGetSecrets(request, ignoreWallet)) {
                 m_calls.removeAt(i);
                 continue;
             }
             break;
         case SecretsRequest::SaveSecrets:
-            if (processSaveSecrets(request)) {
+            if (processSaveSecrets(request, ignoreWallet)) {
                 m_calls.removeAt(i);
                 continue;
             }
             break;
         case SecretsRequest::DeleteSecrets:
-            if (processDeleteSecrets(request)) {
+            if (processDeleteSecrets(request, ignoreWallet)) {
                 m_calls.removeAt(i);
                 continue;
             }
@@ -339,7 +292,7 @@ void SecretAgent::processNext()
     }
 }
 
-bool SecretAgent::processGetSecrets(SecretsRequest &request) const
+bool SecretAgent::processGetSecrets(SecretsRequest &request, bool ignoreWallet) const
 {
     if (m_dialog) {
         return false;
@@ -355,16 +308,21 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     const bool isVpn = (setting->type() == NetworkManager::Setting::Vpn);
 
     NMStringMap secretsMap;
-    if (!requestNew && useWallet()) {
+    if (!ignoreWallet && !requestNew && useWallet()) {
         if (m_wallet->isOpen()) {
             if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
                 QString key = QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % request.setting_name;
                 m_wallet->readMap(key, secretsMap);
             }
         } else {
-            kDebug() << "Waiting for the wallet to open";
+            qDebug() << "Waiting for the wallet to open";
             return false;
         }
+    } else if (!requestNew && !m_wallet) {
+        // If the wallet is disabled fallback to plain text
+        KConfig config("plasma-networkmanagement");
+        KConfigGroup secretsGroup(&config, QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % request.setting_name);
+        secretsMap = secretsGroup.entryMap();
     }
 
     if (!secretsMap.isEmpty()) {
@@ -379,8 +337,8 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
 
     if (requestNew || (allowInteraction && !setting->needSecrets(requestNew).isEmpty()) || (allowInteraction && userRequested) || (isVpn && allowInteraction)) {
         m_dialog = new PasswordDialog(request.connection, request.flags, request.setting_name);
-        connect(m_dialog, SIGNAL(accepted()), this, SLOT(dialogAccepted()));
-        connect(m_dialog, SIGNAL(rejected()), this, SLOT(dialogRejected()));
+        connect(m_dialog, &PasswordDialog::accepted, this, &SecretAgent::dialogAccepted);
+        connect(m_dialog, &PasswordDialog::rejected, this, &SecretAgent::dialogRejected);
         if (isVpn) {
             m_dialog->setupVpnUi(connectionSettings);
         } else {
@@ -406,17 +364,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
         NMVariantMapMap result;
         NetworkManager::VpnSetting::Ptr vpnSetting;
         vpnSetting = connectionSettings.setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
-        //FIXME workaround when NM is asking for secrets which should be system-stored, if we send an empty map it
-        // won't ask for additional secrets with AllowInteraction flag which would display the authentication dialog
-        if (vpnSetting->secretsToMap().isEmpty()) {
-            // Insert an empty secrets map as it was before I fixed it in NetworkManagerQt to make sure NM will ask again
-            // with flags we need
-            QVariantMap secretsMap;
-            secretsMap.insert(QLatin1String("secrets"), QVariant::fromValue<NMStringMap>(NMStringMap()));
-            result.insert("vpn", secretsMap);
-        } else {
-            result.insert("vpn", vpnSetting->secretsToMap());
-        }
+        result.insert("vpn", vpnSetting->secretsToMap());
         sendSecrets(result, request.message);
         return true;
     } else if (setting->needSecrets().isEmpty()) {
@@ -432,9 +380,9 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     }
 }
 
-bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
+bool SecretAgent::processSaveSecrets(SecretsRequest &request, bool ignoreWallet) const
 {
-    if (useWallet()) {
+    if (!ignoreWallet && useWallet()) {
         if (m_wallet->isOpen()) {
             NetworkManager::ConnectionSettings connectionSettings(request.connection);
 
@@ -458,24 +406,36 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
                 return true;
             }
         } else {
-            kDebug() << "Waiting for the wallet to open";
+            qDebug() << "Waiting for the wallet to open";
             return false;
         }
+    } else if (!m_wallet) {
+        NetworkManager::ConnectionSettings connectionSettings(request.connection);
+        KConfig config("plasma-networkmanagement");
+        foreach (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+            KConfigGroup secretsGroup(&config, QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % setting->name());
+            NMStringMap secretsMap = setting->secretsToStringMap();
+            NMStringMap::ConstIterator i = secretsMap.constBegin();
+            while (i != secretsMap.constEnd()) {
+                secretsGroup.writeEntry(i.key(), i.value());
+                ++i;
+            }
+        }
     }
 
     if (!request.saveSecretsWithoutReply) {
         QDBusMessage reply = request.message.createReply();
         if (!QDBusConnection::systemBus().send(reply)) {
-            kWarning() << "Failed put save secrets reply into the queue";
+            qWarning() << "Failed put save secrets reply into the queue";
         }
     }
 
     return true;
 }
 
-bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
+bool SecretAgent::processDeleteSecrets(SecretsRequest &request, bool ignoreWallet) const
 {
-    if (useWallet()) {
+    if (!ignoreWallet && useWallet()) {
         if (m_wallet->isOpen()) {
             if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
                 NetworkManager::ConnectionSettings connectionSettings(request.connection);
@@ -489,14 +449,25 @@ bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
                 }
             }
         } else {
-            kDebug() << "Waiting for the wallet to open";
+            qDebug() << "Waiting for the wallet to open";
             return false;
         }
+    } else if (!m_wallet) {
+        NetworkManager::ConnectionSettings connectionSettings(request.connection);
+
+        KConfig config("plasma-networkmanagement");
+        foreach (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+            foreach (const QString &group, config.groupList()) {
+                if (group.startsWith(QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % setting->name())) {
+                    config.deleteGroup(group);
+                }
+            }
+        }
     }
 
     QDBusMessage reply = request.message.createReply();
     if (!QDBusConnection::systemBus().send(reply)) {
-        kWarning() << "Failed put delete secrets reply into the queue";
+        qWarning() << "Failed put delete secrets reply into the queue";
     }
 
     return true;
@@ -508,21 +479,14 @@ bool SecretAgent::useWallet() const
         return true;
     }
 
-    /* If opening of KWallet failed before, we should not try to open it again and
-     * we should return false instead */
-    if (m_openWalletFailed) {
-        m_openWalletFailed = false;
-        return false;
-    }
-
     if (KWallet::Wallet::isEnabled()) {
         m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), 0, KWallet::Wallet::Asynchronous);
         if (m_wallet) {
-            connect(m_wallet, SIGNAL(walletOpened(bool)), this, SLOT(walletOpened(bool)));
-            connect(m_wallet, SIGNAL(walletClosed()), this, SLOT(walletClosed()));
+            connect(m_wallet, &KWallet::Wallet::walletOpened, this, &SecretAgent::walletOpened);
+            connect(m_wallet, &KWallet::Wallet::walletClosed, this, &SecretAgent::walletClosed);
             return true;
         } else {
-            kWarning() << "Error opening kwallet.";
+            qWarning() << "Error opening kwallet.";
         }
     } else if (m_wallet) {
         m_wallet->deleteLater();
@@ -549,75 +513,6 @@ void SecretAgent::sendSecrets(const NMVariantMapMap &secrets, const QDBusMessage
     QDBusMessage reply;
     reply = message.createReply(QVariant::fromValue(secrets));
     if (!QDBusConnection::systemBus().send(reply)) {
-        kWarning() << "Failed put the secret into the queue";
-    }
-}
-
-void SecretAgent::importSecretsFromPlainTextFiles()
-{
-    KConfig config(QLatin1String("plasma-networkmanagement"), KConfig::SimpleConfig);
-
-    // No action is required when the list of secrets is empty
-    if (!config.groupList().isEmpty()) {
-        foreach (const QString &groupName, config.groupList()) {
-            QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
-            QString loadedSettingType = groupName.split(';').last();
-            NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
-            if (connection) {
-                NetworkManager::Setting::SecretFlags secretFlags = KWallet::Wallet::isEnabled() ? NetworkManager::Setting::AgentOwned : NetworkManager::Setting::None;
-                QMap<QString, QString> secrets = config.entryMap(groupName);
-                NMVariantMapMap settings = connection->settings()->toMap();
-
-                foreach (const QString &setting, settings.keys()) {
-                    if (setting == QLatin1String("vpn")) {
-                        NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
-                        if (vpnSetting) {
-                            // Add loaded secrets from the config file
-                            vpnSetting->secretsFromStringMap(secrets);
-
-                            NMStringMap vpnData = vpnSetting->data();
-                            // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
-                            // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            foreach (const QString &key, vpnData.keys()) {
-                                if (key.endsWith(QLatin1String("-flags"))) {
-                                    vpnData.insert(key, QString::number((int)secretFlags));
-                                }
-                            }
-
-                            vpnSetting->setData(vpnData);
-                            settings.insert(setting, vpnSetting->toMap());
-                            connection->update(settings);
-                        }
-                    } else {
-                        if (setting == loadedSettingType) {
-                            QVariantMap tmpSetting = settings.value(setting);
-                            // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
-                            // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            foreach (const QString &key, tmpSetting.keys()) {
-                                if (key.endsWith(QLatin1String("-flags"))) {
-                                    tmpSetting.insert(key, (int)secretFlags);
-                                }
-                            }
-
-                            // Add loaded secrets from the config file
-                            QMap<QString, QString>::const_iterator it = secrets.constBegin();
-                            QMap<QString, QString>::const_iterator end = secrets.constEnd();
-                            for (; it != end; ++it) {
-                                tmpSetting.insert(it.key(), it.value());
-                            }
-
-                            // Replace the old setting with the new one
-                            settings.insert(setting, tmpSetting);
-                            // Update the connection which re-saves secrets
-                            connection->update(settings);
-                        }
-                    }
-                }
-            }
-
-            // Remove the group
-            KConfigGroup group(&config, groupName);
-            group.deleteGroup();
-        }
+        qWarning() << "Failed put the secret into the queue";
     }
 }
