@@ -75,8 +75,6 @@ QVariant EditorIdentityModel::data(const QModelIndex& index, int role) const
     const QString lastUsed = sourceModel()->data(sourceIndex, NetworkModel::LastUsedDateOnlyRole).toString();
     const bool isActivated = (NetworkManager::ActiveConnection::State) sourceModel()->data(sourceIndex, NetworkModel::ConnectionStateRole).toInt()
                              == NetworkManager::ActiveConnection::Activated;
-    const bool isActivating = (NetworkManager::ActiveConnection::State) sourceModel()->data(sourceIndex, NetworkModel::ConnectionStateRole).toInt()
-                             == NetworkManager::ActiveConnection::Activating;
     NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(sourceModel()->data(sourceIndex, NetworkModel::TypeRole).toInt());
     QString tooltip;
     QString iconName = UiUtils::iconAndTitleForConnectionSettingsType(type, tooltip);
@@ -88,6 +86,9 @@ QVariant EditorIdentityModel::data(const QModelIndex& index, int role) const
             if (type == NetworkManager::ConnectionSettings::Infiniband ||
                 type == NetworkManager::ConnectionSettings::Bond ||
                 type == NetworkManager::ConnectionSettings::Bridge ||
+#if NM_CHECK_VERSION(0, 9, 10)
+                type == NetworkManager::ConnectionSettings::Team ||
+#endif
                 type == NetworkManager::ConnectionSettings::Vlan) {
                 return QString(connectionName + " (" + NetworkManager::ConnectionSettings::typeAsString(type) + ")");
             }
@@ -107,10 +108,6 @@ QVariant EditorIdentityModel::data(const QModelIndex& index, int role) const
             QFont f;
             f.setBold(true);
             return f;
-        } else if (column == 0 && isActivating) {
-            QFont f;
-            f.setItalic(true);
-            return f;
         }
     } else {
         return sourceModel()->data(index, role);
