@@ -51,14 +51,13 @@ private:
     void addFormInfo(const QString &, const QString &);
     void deleteAllFromLayout(QLayout *);
 
-private slots:
+private Q_SLOTS:
     void writeNewConfig(const QString &);
     void validatePeerCert(const QString &, const QString &, const QString &, bool*);
     void processAuthForm(struct oc_auth_form *);
     void updateLog(const QString &, const int &);
     void logLevelChanged(int);
     void formLoginClicked();
-    void formGroupChanged();
     void workerFinished(const int&);
     void viewServerLogToggled(bool);
     void passwordModeToggled(bool);
