@@ -26,8 +26,7 @@
 #include "pptpwidget.h"
 #include "pptpauth.h"
 
-K_PLUGIN_FACTORY(PptpUiPluginFactory, registerPlugin<PptpUiPlugin>();)
-K_EXPORT_PLUGIN(PptpUiPluginFactory("plasmanetworkmanagement_pptpui"))
+K_PLUGIN_FACTORY_WITH_JSON(PptpUiPluginFactory, "plasmanetworkmanagement_pptpui.json", registerPlugin<PptpUiPlugin>();)
 
 PptpUiPlugin::PptpUiPlugin(QObject * parent, const QVariantList &) : VpnUiPlugin(parent)
 {
@@ -79,3 +78,5 @@ bool PptpUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionSett
     mError = VpnUiPlugin::NotImplemented;
     return false;
 }
+
+#include "pptp.moc"
