@@ -23,10 +23,7 @@
 
 #include <NetworkManagerQt/VpnSetting>
 
-#include <QPointer>
-
 #include "settingwidget.h"
-#include "vpncadvancedwidget.h"
 
 namespace Ui
 {
@@ -46,7 +43,7 @@ public:
 
     virtual bool isValid() const;
 
-private slots:
+private Q_SLOTS:
     void userPasswordTypeChanged(int index);
     void groupPasswordTypeChanged(int index);
     void showPasswords(bool show);
@@ -56,7 +53,6 @@ private:
     Ui::VpncWidget * m_ui;
     NetworkManager::VpnSetting::Ptr m_setting;
     NetworkManager::VpnSetting::Ptr m_tmpSetting;
-    QPointer<VpncAdvancedWidget> m_advancedWidget;
 };
 
 #endif // PLASMA_NM_VPNC_WIDGET_H
